%%%%%%%%%%%%%%%%%%%%%%%%%%%%
Maastricht Diffusion Toolbox
%%%%%%%%%%%%%%%%%%%%%%%%%%%%

############
Introduction
############

.. include:: ../README.rst
   :start-line: 3


.. toctree::
    :maxdepth: 2
    :hidden:

    install
    concepts
    getting_started
    dynamic_modules
    configuration
    FAQ <faq>
    credits
    developers
